# jumly

`jumly` - a unified framework for multi-paradigm machine learning research.

Short for "Jake's Utilities for Machine Learning research, using jutilitY" (because `juml` [clashed](https://stackoverflow.com/a/71490005/8477566) with [`jumi`](https://pypi.org/project/jumi/)).
